Meta Package Manager — Meta Package Manager 2.4.0 documentation

# Meta Package Manager

CLI providing unifying interface to all package managers.

Stable release:

Development:

Source: XKCD #1654.

## Features

- Search and list all package managers on the system.
- Supports macOS and Linux.
- List installed packages.
- List outdated packages.
- Sync local package infos.
- Upgrade all outdated packages.
- Apply commands per-package manager or to all of them.
- Export results in JSON or user-friendly tables.
- Provides a BitBar plugin for friendly macOS integration.

## Supported package managers

Package manager | Version | macOS | Linux | Windows | `sync` | `list` | `search` | `install` | `outdated` | `upgrade`
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
Homebrew | >= 1.0.* | ✅ |  |  | ✅ | ✅ |  |  | ✅ | ✅
Homebrew Cask | >= 1.0.* | ✅ |  |  | ✅ | ✅ |  |  | ✅ | ✅
Python 2 `pip` |  | ✅ | ✅ |  |  | ✅ |  |  | ✅ | ✅
Python 3 `pip` |  | ✅ | ✅ |  |  | ✅ |  |  | ✅ | ✅
Node’s `npm` |  | ✅ |  |  |  | ✅ |  |  | ✅ | ✅
Atom’s `apm` |  | ✅ |  |  |  | ✅ |  |  | ✅ | ✅
Ruby’s `gem` |  | ✅ |  |  |  | ✅ |  |  | ✅ | ✅
Mac AppStore via `mas` | >= 1.3.1 | ✅ |  |  |  | ✅ |  |  | ✅ | ✅

If you’re bored, feel free to add support for new package manager. See the list of good candidates.

## Usage

Examples of the package’s `mpm` CLI.

List global options and commands:

    $ mpm
    Usage: mpm [OPTIONS] COMMAND [ARGS]...

      CLI for multi-package manager upgrades.

    Options:
      -v, --verbosity LEVEL           Either CRITICAL, ERROR, WARNING, INFO or
                                      DEBUG. Defaults to INFO.
      -m, --manager [npm|mas|pip3|pip2|cask|apm|brew|gem]
                                      Restrict sub-command to one package manager.
                                      Defaults to all.
      -o, --output-format [simple|plain|json|fancy]
                                      Rendering mode of the output. Defaults to
                                      fancy.
      --version                       Show the version and exit.
      --help                          Show this message and exit.

    Commands:
      managers  List supported package managers and their location.
      outdated  List outdated packages.
      sync      Sync local package info.
      upgrade   Upgrade all packages.

List all supported package managers and their status on current system:

    $ mpm managers
    ╒═══════════════════╤══════╤═════════════╤════════════════════════╤══════════════╤═════════════╕
    │ Package manager   │ ID   │ Supported   │ CLI                    │ Executable   │ Version     │
    ╞═══════════════════╪══════╪═════════════╪════════════════════════╪══════════════╪═════════════╡
    │ Atom's apm        │ apm  │ ✓           │ ✓  /usr/local/bin/apm  │ ✓            │ ✓  1.12.9   │
    ├───────────────────┼──────┼─────────────┼────────────────────────┼──────────────┼─────────────┤
    │ Homebrew          │ brew │ ✓           │ ✓  /usr/local/bin/brew │ ✓            │ ✓  1.1.7    │
    ├───────────────────┼──────┼─────────────┼────────────────────────┼──────────────┼─────────────┤
    │ Homebrew Cask     │ cask │ ✓           │ ✓  /usr/local/bin/brew │ ✓            │ ✓  1.1.7    │
    ├───────────────────┼──────┼─────────────┼────────────────────────┼──────────────┼─────────────┤
    │ Ruby Gems         │ gem  │ ✓           │ ✓  /usr/bin/gem        │ ✓            │ ✓  2.0.14.1 │
    ├───────────────────┼──────┼─────────────┼────────────────────────┼──────────────┼─────────────┤
    │ Mac AppStore      │ mas  │ ✓           │ ✓  /usr/local/bin/mas  │ ✓            │ ✓  1.3.1    │
    ├───────────────────┼──────┼─────────────┼────────────────────────┼──────────────┼─────────────┤
    │ Node's npm        │ npm  │ ✓           │ ✓  /usr/local/bin/npm  │ ✓            │ ✓  4.0.5    │
    ├───────────────────┼──────┼─────────────┼────────────────────────┼──────────────┼─────────────┤
    │ Python 2's Pip    │ pip2 │ ✓           │ ✓  /usr/local/bin/pip2 │ ✓            │ ✓  9.0.1    │
    ├───────────────────┼──────┼─────────────┼────────────────────────┼──────────────┼─────────────┤
    │ Python 3's Pip    │ pip3 │ ✓           │ ✓  /usr/local/bin/pip3 │ ✓            │ ✓  9.0.1    │
    ╘═══════════════════╧══════╧═════════════╧════════════════════════╧══════════════╧═════════════╛

# Contents

- Installation
- Falsehoods Programmers Believe About Package Managers
  - Packages
  - Package Managers
  - Meta
- BitBar Plugin
  - Development workflow
  - Release process
- meta_package_manager package
  - Subpackages
  - Submodules
- Development
  - Philosophy
  - Stability policy
  - Build status
  - Setup a development environment
  - Unit-tests
  - Coding style
  - Build documentation
  - Release process
- Changelog
  - 2.4.0 (unreleased)
  - 2.3.0 (2017-01-15)
  - 2.2.0 (2016-12-25)
  - 2.1.1 (2016-12-17)
  - 2.1.0 (2016-12-14)
  - 2.0.0 (2016-12-04)
  - 1.12.0 (2016-12-03)
  - 1.11.0 (2016-11-30)
  - 1.10.0 (2016-10-04)
  - 1.9.0 (2016-09-23)
  - 1.8.0 (2016-08-22)
  - 1.7.0 (2016-08-16)
  - 1.6.0 (2016-08-10)
  - 1.5.0 (2016-07-25)
  - 1.4.0 (2016-07-10)
  - 1.3.0 (2016-07-09)
  - 1.2.0 (2016-07-08)
  - 1.1.0 (2016-07-07)
  - 1.0.0 (2016-07-05)
- Todo list
- History
- License

# Indices and tables

- Index
- Module Index
- Search Page